@@ -4,7 +4,7 @@ from markdown_it import MarkdownIt
 from markdown_it.common.utils import escapeHtml
 from markdown_it.rules_inline import StateInline
 
-PATTERN = re.compile(r"^\{([a-zA-Z0-9\_\-\+\:]{1,36})\}(`+)(?!`)(.+?)(?<!`)\2(?!`)")
+VALID_NAME_PATTERN = re.compile(r"^\{([a-zA-Z0-9\_\-\+\:]+)\}")
 
 
 def myst_role_plugin(md: MarkdownIt):
@@ -14,6 +14,13 @@ def myst_role_plugin(md: MarkdownIt):
 
 
 def myst_role(state: StateInline, silent: bool):
+    # check name
+    match = VALID_NAME_PATTERN.match(state.src[state.pos :])
+    if not match:
+        return False
+    name = match.group(1)
+
+    # check for starting backslash escape
     try:
         if state.srcCharCode[state.pos - 1] == 0x5C:  # /* \ */
             # escaped (this could be improved in the case of edge case '\\{')
@@ -21,15 +28,30 @@ def myst_role(state: StateInline, silent: bool):
     except IndexError:
         pass
 
-    match = PATTERN.search(state.src[state.pos :])
+    # scan opening tick length
+    start = pos = state.pos + match.end()
+    try:
+        while state.src[pos] == "`":
+            pos += 1
+    except IndexError:
+        return False
+
+    tick_length = pos - start
+    if not tick_length:
+        return False
+
+    # search for closing ticks
+    match = re.search("`" * tick_length, state.src[pos + 1 :])
     if not match:
         return False
-    state.pos += match.end()
+    content = state.src[pos : pos + match.start() + 1].replace("\n", " ")
 
     if not silent:
         token = state.push("myst_role", "", 0)
-        token.meta = {"name": match.group(1)}
-        token.content = match.group(3)
+        token.meta = {"name": name}
+        token.content = content
+
+    state.pos = pos + match.end() + 1
 
     return True
 
@@ -37,8 +59,4 @@ def myst_role(state: StateInline, silent: bool):
 def render_myst_role(self, tokens, idx, options, env):
     token = tokens[idx]
     name = token.meta.get("name", "unknown")
-    return (
-        '<code class="sphinx-role">'
-        f"{{{name}}}[{escapeHtml(token.content)}]"
-        "</code>"
-    )
+    return f'<code class="myst role">{{{name}}}[{escapeHtml(token.content)}]</code>'
